==> qtbase-opensource-src-5.1.1.tar.xz: qtbase-opensource-src-5.1.1/src/plugins/platforms/ios/qioscontext.h <==
/****************************************************************************
**
** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of the plugins of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
**
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QIOSCONTEXT_H
#define QIOSCONTEXT_H

#include <qpa/qplatformopenglcontext.h>

@class EAGLContext;

QT_BEGIN_NAMESPACE

class QIOSContext : public QObject, public QPlatformOpenGLContext
{
    Q_OBJECT

public:
    QIOSContext(QOpenGLContext *context);
    ~QIOSContext();

    QSurfaceFormat format() const;

    void swapBuffers(QPlatformSurface *surface);

    bool makeCurrent(QPlatformSurface *surface);
    void doneCurrent();

    GLuint defaultFramebufferObject(QPlatformSurface *) const;
    QFunctionPointer getProcAddress(const QByteArray &procName);

private Q_SLOTS:
    void windowDestroyed(QObject *object);

private:
    EAGLContext *m_eaglContext;
    QSurfaceFormat m_format;

    struct FramebufferObject {
        GLuint handle;
        GLuint colorRenderbuffer;
        GLuint depthRenderbuffer;
        GLint renderbufferWidth;
        GLint renderbufferHeight;
    };

    static void deleteBuffers(const FramebufferObject &framebufferObject);

    mutable QHash<QWindow *, FramebufferObject> m_framebufferObjects;
};

QT_END_NAMESPACE

#endif // QIOSCONTEXT_H

==> qtbase-opensource-src-5.3.1.tar.xz: qtbase-opensource-src-5.3.1/src/plugins/platforms/ios/qioscontext.h <==
/****************************************************************************
**
** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of the plugins of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
**
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QIOSCONTEXT_H
#define QIOSCONTEXT_H

#include <qpa/qplatformopenglcontext.h>

@class EAGLContext;

QT_BEGIN_NAMESPACE

class QIOSWindow;

class QIOSContext : public QObject, public QPlatformOpenGLContext
{
    Q_OBJECT

public:
    QIOSContext(QOpenGLContext *context);
    ~QIOSContext();

    QSurfaceFormat format() const;

    void swapBuffers(QPlatformSurface *surface);

    bool makeCurrent(QPlatformSurface *surface);
    void doneCurrent();

    GLuint defaultFramebufferObject(QPlatformSurface *) const;
    QFunctionPointer getProcAddress(const QByteArray &procName);

    bool isSharing() const Q_DECL_OVERRIDE;
    bool isValid() const Q_DECL_OVERRIDE;

private Q_SLOTS:
    void windowDestroyed(QObject *object);

private:
    QIOSContext *m_sharedContext;
    EAGLContext *m_eaglContext;
    QSurfaceFormat m_format;

    struct FramebufferObject {
        GLuint handle;
        GLuint colorRenderbuffer;
        GLuint depthRenderbuffer;
        GLint renderbufferWidth;
        GLint renderbufferHeight;
        bool isComplete;
    };

    static void deleteBuffers(const FramebufferObject &framebufferObject);

    FramebufferObject &backingFramebufferObjectFor(QPlatformSurface *) const;
    mutable QHash<QIOSWindow *, FramebufferObject> m_framebufferObjects;
};

QT_END_NAMESPACE

#endif // QIOSCONTEXT_H
